{% load admin_modify admin_urls i18n %}

{% if inline_admin_form.original %}
    <span class="ml-2 font-normal leading-none text-xs text-primary-600 dark:text-primary-500 group-hover/title:block hidden">
        {% if inline_admin_form.model_admin.show_change_link and inline_admin_form.model_admin.has_registered_model %}
            <a href="{% url inline_admin_form.model_admin.opts|admin_urlname:'change' inline_admin_form.original.pk|admin_urlquote %}" class="align-middle">
                {% trans "Change" %}
            </a>
        {% endif %}

        {% if inline_admin_form.show_url and inline_admin_form.model_admin.show_change_link and inline_admin_form.model_admin.has_registered_model %}
            <span class="align-middle bg-base-300 inline-block h-3 mx-1.5 w-px dark:bg-base-700"></span>
        {% endif %}

        {% if inline_admin_form.show_url %}
            <a href="{{ inline_admin_form.absolute_url }}" class="align-middle" target="_blank">
                {% trans "View" %}
            </a>
        {% endif %}
    </span>
{% endif %}
