<div id="{{ inline_admin_formset.formset.prefix }}-group" data-inline-type="stacked" {% if inline_admin_formset.opts.tab %}x-show="activeTab == '{{ inline_admin_formset.formset.prefix|slugify }}'"{% else %}x-show="activeTab == 'general'"{% endif %}>
    <fieldset class="module relative {{ inline_admin_formset.classes }}" aria-labelledby="{{ inline_admin_formset.formset.prefix }}-heading">
        {% if inline_admin_formset.is_collapsible %}<details><summary class="*:mb-0">{% endif %}

        {% include "unfold/helpers/inline_heading.html" %}

        {% if inline_admin_formset.is_collapsible %}</summary>{% endif %}

        {% include "unfold/helpers/edit_inline/stacked_list.html" %}

        {% if inline_admin_formset.is_collapsible %}</details>{% endif %}
    </fieldset>
</div>
