from setuptools import setup, find_packages

setup(
    name="django_unfold_conf",
    version="0.86.4",
    packages=find_packages(where="django-unfold/src"),
    package_dir={"": "django-unfold/src"},
    include_package_data=True,
    package_data={
        "": [
            "templates/**/*",
            "static/**/*",
        ],
    },
    zip_safe=False,
    install_requires=[],
    description="This is a package forked from https://unfoldadmin.com/ that I made some adjustments, hereby I fully credit the original author.",
)