<h2 id="{{ inline_admin_formset.formset.prefix }}-heading" class="bg-base-100 font-semibold mb-6 px-4 py-3 rounded-default text-font-important-light @min-[1570px]:-mx-4 dark:bg-white/[.02] dark:text-font-important-dark {% if inline_admin_formset.opts.tab %}hidden{% endif %} {% if inline_admin_formset.is_collapsible %} cursor-pointer{% endif %}">
    {% if inline_admin_formset.formset.max_num == 1 %}
        {{ inline_admin_formset.opts.verbose_name|capfirst }}
    {% else %}
        {{ inline_admin_formset.opts.verbose_name_plural|capfirst }}
    {% endif %}
</h2>
