<div class="hidden form-actions border-t border-base-200 flex flex-row justify-between p-3 dark:border-base-800 items-center gap-4 has-[.add-row:not(.hidden)]:flex has-[.inline-pagination]:flex group-[.empty]/formset-parent:!border-t-0 group-[.empty]/formset-nested:!border-t-0">
    {% include "unfold/helpers/edit_inline/inline_add.html" %}

    {% include "unfold/helpers/pagination_inline.html" %}
</div>
